@@ -1,8 +1,10 @@
 import yaml
 from lark import Discard
 from lark.visitors import Interpreter, Transformer
-from gersemi.ast_helpers import is_keyword
+from gersemi.ast_helpers import get_value, is_keyword
+from gersemi.immutable import make_immutable
 from gersemi.keywords import Hint, Keywords
+from gersemi.keyword_kind import KeywordFormatter, KeywordPreprocessor
 
 
 class IgnoreThisDefinition:
@@ -46,9 +48,6 @@ class DropIrrelevantElements(Transformer):
     bracket_comment = _discard
 
 
-is_parse_argv = is_keyword("PARSE_ARGV")
-
-
 class CMakeInterpreter(Interpreter):
     def __init__(self, filepath, stack=None):
         self.stack = {} if stack is None else stack
@@ -80,7 +79,7 @@ class CMakeInterpreter(Interpreter):
         raise RuntimeError
 
     def _cmake_parse_arguments(self, arguments):
-        if is_parse_argv(arguments.children[0]):
+        if is_keyword("PARSE_ARGV", arguments.children[0]):
             keywords = arguments.children[3:6]
         else:
             keywords = arguments.children[1:4]
@@ -139,6 +138,8 @@ class CMakeInterpreter(Interpreter):
         hint = self._get_hint(tree)
         subinterpreter = self._inner_scope
         block_begin, *body, _ = subinterpreter.visit_children(tree)
+        self.found_commands.update(subinterpreter.found_commands)
+
         command_node, *_ = block_begin
         if command_node is None:
             return
@@ -177,7 +178,7 @@ class CMakeInterpreter(Interpreter):
         return tree.children[0]
 
     def quoted_argument(self, tree):
-        return tree.children[0] if tree.children else ""
+        return get_value(tree, "")
 
     bracket_argument = _join
     commented_argument = _join
@@ -189,10 +190,30 @@ def find_custom_command_definitions(tree, filepath="---"):
     return CMakeInterpreter(filepath).visit(tree)
 
 
+def create_command(canonical_name, positional_arguments, keywords):
+    return {
+        "_canonical_name": canonical_name,
+        "front_positional_arguments": positional_arguments,
+        "options": keywords.options,
+        "one_value_keywords": keywords.one_value_keywords,
+        "multi_value_keywords": keywords.multi_value_keywords,
+        "keyword_formatters": {
+            hint.keyword: hint.kind
+            for hint in keywords.hints
+            if hint.kind in [e.value for e in KeywordFormatter]
+        },
+        "keyword_preprocessors": {
+            hint.keyword: hint.kind
+            for hint in keywords.hints
+            if hint.kind in [e.value for e in KeywordPreprocessor]
+        },
+    }
+
+
 def get_just_definitions(definitions):
     result = {}
     for name, info in definitions.items():
         sorted_info = list(sorted(info, key=lambda item: item[1]))
-        (canonical_name, arguments), _ = sorted_info[0]
-        result[name] = canonical_name, arguments
-    return result
+        (canonical_name, (positional_arguments, keywords)), _ = sorted_info[0]
+        result[name] = create_command(canonical_name, positional_arguments, keywords)
+    return make_immutable(result)
