@@ -1,5 +1,6 @@
 from dataclasses import dataclass
 from pathlib import Path
+from gersemi.warnings import FormatterWarnings
 
 
 @dataclass
@@ -8,3 +9,4 @@ class TaskResult:
     return_code: int
     to_stdout: str = ""
     to_stderr: str = ""
+    warnings: FormatterWarnings = tuple()
